# - Try to find CAIRO
# Once done this will define
#
#  CAIRO_ROOT_DIR - Set this variable to the root installation of CAIRO
#  CAIRO_FOUND - system has CAIRO
#  CAIRO_INCLUDE_DIR - the CAIRO include directory
#  CAIRO_INCLUDE_DIRS - all of the CAIRO include directory
#  CAIRO_LIBRARY - the CAIRO library
#  CAIRO_LIBRARIES - all of the CAIRO libraries
#
#  Copyright (c) 2008 Joshua L. Blocher <verbalshadow at gmail dot com>
#  Copyright (c) 2012 Dmitry Baryshnikov <polimax at mail dot ru>
#  Copyright (c) 2013 Michael Pavlyshko <pavlushko at tut dot by>
#
# Distributed under the OSI-approved BSD License
#

if (NOT WIN32)
    find_package(PkgConfig)
    if (PKG_CONFIG_FOUND)
        pkg_check_modules(_CAIRO glib)
    endif (PKG_CONFIG_FOUND)
endif (NOT WIN32)

SET(_CAIRO_ROOT_HINTS
    $ENV{CAIRO}
    ${CMAKE_FIND_ROOT_PATH}
    ${CAIRO_ROOT_DIR}
) 

SET(_CAIRO_ROOT_PATHS
    $ENV{CAIRO}/src
    /usr
    /usr/local
)

SET(_CAIRO_ROOT_HINTS_AND_PATHS
    HINTS ${_CAIRO_ROOT_HINTS}
    PATHS ${_CAIRO_ROOT_PATHS}
)

FIND_PATH(CAIRO_INCLUDE_DIR
    NAMES
        "cairo.h"
    HINTS
        ${_CAIRO_INCLUDEDIR}
        ${_CAIRO_ROOT_HINTS_AND_PATHS}
    PATH_SUFFIXES
        include
        "include/cairo"
)  

FIND_LIBRARY(CAIRO_LIBRARY
    NAMES
        cairo
    HINTS
        ${_CAIRO_LIBDIR}
        ${_CAIRO_ROOT_HINTS_AND_PATHS}
    PATH_SUFFIXES
        "lib"
        "local/lib"
) 

if(GLIB_FOUND)
FIND_LIBRARY(CAIRO_GOBJECT_LIBRARY
    NAMES
        cairo-gobject
    HINTS
        ${_CAIRO_LIBDIR}
        ${_CAIRO_ROOT_HINTS_AND_PATHS}
    PATH_SUFFIXES
        "lib"
        "local/lib"
) 
endif(GLIB_FOUND)

SET(CAIRO_LIBRARIES 
    ${CAIRO_LIBRARY}
    ${CAIRO_GOBJECT_LIBRARY}
)

SET(CAIRO_INCLUDE_DIRS
    ${CAIRO_INCLUDE_DIR}
)

include(FindPackageHandleStandardArgs)
find_package_handle_standard_args(CAIRO
    REQUIRED_VARS CAIRO_LIBRARIES CAIRO_INCLUDE_DIRS
    FAIL_MESSAGE "Could NOT find CAIRO, try to set the path to CAIRO root folder in the system variable CAIRO"
)

MARK_AS_ADVANCED(CAIRO_INCLUDE_DIR CAIRO_INCLUDE_DIRS CAIRO_LIBRARY CAIRO_GOBJECT_LIBRARY CAIRO_LIBRARIES )

