# - Try to find GLIB
# Once done this will define
#
#  GLIB_ROOT_DIR - Set this variable to the root installation of GLIB
#  GLIB_FOUND - system has GLIB
#  GLIB_INCLUDE_DIR - the GLIB include directory
#  GLIB_CONFIG_INCLUDE_DIR - the GLIB config include directory
#  GLIB_INCLUDE_DIRS - all of the GLIB include directory
#  GLIB_LIBRARY - the glib library
#  GOBJECT_LIBRARY - the gobject library
#  GMODULE_LIBRARY - the gmodule library
#  GLIB_LIBRARIES - all of the GLIB libraries
#
#  Copyright (c) 2008 Joshua L. Blocher <verbalshadow at gmail dot com>
#  Copyright (c) 2012 Dmitry Baryshnikov <polimax at mail dot ru>
#  Copyright (c) 2013 Michael Pavlyshko <pavlushko at tut dot by>
#
# Distributed under the OSI-approved BSD License
#

if (NOT WIN32)
    find_package(PkgConfig)
    if (PKG_CONFIG_FOUND)
        pkg_check_modules(_GLIB glib)
    endif (PKG_CONFIG_FOUND)
endif (NOT WIN32)

SET(_GLIB_ROOT_HINTS
    $ENV{GLIB}
    ${CMAKE_FIND_ROOT_PATH}
    ${GLIB_ROOT_DIR}
) 

SET(_GLIB_ROOT_PATHS
    $ENV{GLIB}/src
    /usr
    /usr/local
)

SET(_GLIB_ROOT_HINTS_AND_PATHS
    HINTS ${_GLIB_ROOT_HINTS}
    PATHS ${_GLIB_ROOT_PATHS}
)

FIND_PATH(GLIB_INCLUDE_DIR
    NAMES
        "glib.h"
    HINTS
        ${_GLIB_INCLUDEDIR}
        ${_GLIB_ROOT_HINTS_AND_PATHS}
    PATH_SUFFIXES
        include
        "include/glib-2.0"
)  

FIND_PATH(GLIB_CONFIG_INCLUDE_DIR
    NAMES
        "glibconfig.h"
    HINTS
        ${_GLIB_INCLUDEDIR}
        ${_GLIB_ROOT_HINTS_AND_PATHS}
    PATH_SUFFIXES
        lib/glib-2.0/include
)  

FIND_LIBRARY(GLIB_LIBRARY
    NAMES
        glib-2.0
    HINTS
        ${_GLIB_LIBDIR}
        ${_GLIB_ROOT_HINTS_AND_PATHS}
    PATH_SUFFIXES
        "lib"
        "local/lib"
) 

FIND_LIBRARY(GOBJECT_LIBRARY
    NAMES
        gobject-2.0
    HINTS
        ${_GLIB_LIBDIR}
        ${_GLIB_ROOT_HINTS_AND_PATHS}
    PATH_SUFFIXES
        "lib"
        "local/lib"
) 

FIND_LIBRARY(GMODULE_LIBRARY
    NAMES
        gmodule-2.0
    HINTS
        ${_GLIB_LIBDIR}
        ${_GLIB_ROOT_HINTS_AND_PATHS}
    PATH_SUFFIXES
        "lib"
        "local/lib"
) 

SET(GLIB_LIBRARIES 
    ${GLIB_LIBRARY} 
    ${GOBJECT_LIBRARY}
    ${GMODULE_LIBRARY}
)

SET(GLIB_INCLUDE_DIRS
    ${GLIB_INCLUDE_DIR}
    ${GLIB_CONFIG_INCLUDE_DIR}
)

include(FindPackageHandleStandardArgs)
find_package_handle_standard_args(GLIB
    REQUIRED_VARS GLIB_LIBRARIES GLIB_INCLUDE_DIRS
    FAIL_MESSAGE "Could NOT find GLIB, try to set the path to GLIB root folder in the system variable GLIB"
)

MARK_AS_ADVANCED(GLIB_INCLUDE_DIR GLIB_CONFIG_INCLUDE_DIR GLIB_INCLUDE_DIRS GLIB_LIBRARY GOBJECT_LIBRARY GMODULE_LIBRARY GLIB_LIBRARIES )

